pub struct PackedItem {
pub item_sequence_number: i32,
pub buyer_product_identifier: Option<String>,
pub vendor_product_identifier: Option<String>,
pub packed_quantity: Box<ItemQuantity>,
}Fields
item_sequence_number: i32Item Sequence Number for the item. This must be the same value as sent in the order for a given item.
buyer_product_identifier: Option<String>Buyer’s Standard Identification Number (ASIN) of an item. Either buyerProductIdentifier or vendorProductIdentifier is required.
vendor_product_identifier: Option<String>The vendor selected product identification of the item. Should be the same as was sent in the Purchase Order, like SKU Number.
packed_quantity: Box<ItemQuantity>Implementations
sourceimpl PackedItem
impl PackedItem
pub fn new(
item_sequence_number: i32,
packed_quantity: ItemQuantity
) -> PackedItem